@@ -77,23 +77,23 @@ typedef struct {
   long		de_flags;			/* default settings */
 } default_t;
 
-#define RUNTIME_FLAGS	(DEBUG_LOG_STATS | DEBUG_LOG_NONFREE | \
-			 DEBUG_LOG_BAD_SPACE | \
-			 DEBUG_CHECK_FENCE | \
-			 DEBUG_CATCH_NULL)
+#define RUNTIME_FLAGS	(DMALLOC_DEBUG_LOG_STATS | DMALLOC_DEBUG_LOG_NONFREE | \
+			 DMALLOC_DEBUG_LOG_BAD_SPACE | \
+			 DMALLOC_DEBUG_CHECK_FENCE | \
+			 DMALLOC_DEBUG_CATCH_NULL)
 #define LOW_FLAGS	(RUNTIME_FLAGS | \
-			 DEBUG_LOG_ELAPSED_TIME | \
-			 DEBUG_CHECK_SHUTDOWN | \
-			 DEBUG_FREE_BLANK | DEBUG_ERROR_ABORT | \
-			 DEBUG_ALLOC_BLANK)
+			 DMALLOC_DEBUG_LOG_ELAPSED_TIME | \
+			 DMALLOC_DEBUG_CHECK_SHUTDOWN | \
+			 DMALLOC_DEBUG_FREE_BLANK | DMALLOC_DEBUG_ERROR_ABORT | \
+			 DMALLOC_DEBUG_ALLOC_BLANK)
 #define MEDIUM_FLAGS	(LOW_FLAGS | \
-			 DEBUG_CHECK_HEAP | \
-			 DEBUG_REALLOC_COPY)
+			 DMALLOC_DEBUG_CHECK_HEAP | \
+			 DMALLOC_DEBUG_REALLOC_COPY)
 #define HIGH_FLAGS	(MEDIUM_FLAGS | \
-			 DEBUG_CHECK_BLANK | DEBUG_CHECK_FUNCS)
+			 DMALLOC_DEBUG_CHECK_BLANK | DMALLOC_DEBUG_CHECK_FUNCS)
 #define ALL_FLAGS	(HIGH_FLAGS | \
-			 DEBUG_LOG_TRANS | DEBUG_LOG_ADMIN | \
-			 DEBUG_NEVER_REUSE)
+			 DMALLOC_DEBUG_LOG_TRANS | DMALLOC_DEBUG_LOG_ADMIN | \
+			 DMALLOC_DEBUG_NEVER_REUSE)
 /* NOTE: print-messages is not in this list because it is special */
 
 static	default_t	defaults[] = {
