@@ -111,7 +111,7 @@ static	void	*heap_extend(const int incr)
 #endif /* if not INTERNAL_MEMORY_SPACE */
   
   if (ret == SBRK_ERROR) {
-    if (BIT_IS_SET(_dmalloc_flags, DEBUG_CATCH_NULL)) {
+    if (BIT_IS_SET(_dmalloc_flags, DMALLOC_DEBUG_CATCH_NULL)) {
       char	str[128];
       int	len;
       len = loc_snprintf(str, sizeof(str),
@@ -119,7 +119,7 @@ static	void	*heap_extend(const int incr)
       (void)write(STDERR, str, len);
       _dmalloc_die(0);
     }
-    dmalloc_errno = ERROR_ALLOC_FAILED;
+    dmalloc_errno = DMALLOC_ERROR_ALLOC_FAILED;
     dmalloc_error("heap_extend");
   }
   
@@ -131,10 +131,9 @@ static	void	*heap_extend(const int incr)
     _dmalloc_heap_high = high;
   }
   
-  if (BIT_IS_SET(_dmalloc_flags, DEBUG_LOG_ADMIN)) {
-    dmalloc_message("extended heap space by %d bytes returned %#lx [%#lx, %#lx]",
-		    incr, (unsigned long)ret, (unsigned long)_dmalloc_heap_low,
-		    (unsigned long)_dmalloc_heap_high);
+  if (BIT_IS_SET(_dmalloc_flags, DMALLOC_DEBUG_LOG_ADMIN)) {
+    dmalloc_message("extended heap space by %d bytes returned %p [%p, %p]",
+		    incr, ret, _dmalloc_heap_low, _dmalloc_heap_high);
   }
   
   return ret;
@@ -163,13 +162,12 @@ static	void	heap_release(void *addr, const int size)
 #else
 #if HAVE_MUNMAP && USE_MMAP
   if (munmap(addr, size) == 0) {
-    if (BIT_IS_SET(_dmalloc_flags, DEBUG_LOG_ADMIN)) {
-      dmalloc_message("releasing heap memory %#lx, size %d",
-		      (unsigned long)addr, size);
+    if (BIT_IS_SET(_dmalloc_flags, DMALLOC_DEBUG_LOG_ADMIN)) {
+      dmalloc_message("releasing heap memory %p, size %d", addr, size);
     }
   } else {
-    dmalloc_message("munmap failed to release heap memory %#lx, size %d",
-		    (unsigned long)addr, size);
+    dmalloc_message("munmap failed to release heap memory %p, size %d",
+		    addr, size);
   }
 #else
   /* no-op */
@@ -224,7 +222,7 @@ void	*_dmalloc_heap_alloc(const unsigned int size)
   long	diff_size;
   
   if (size == 0) {
-    dmalloc_errno = ERROR_BAD_SIZE;
+    dmalloc_errno = DMALLOC_ERROR_BAD_SIZE;
     dmalloc_error("_dmalloc_heap_alloc");
     return HEAP_ALLOC_ERROR;
   }
@@ -275,8 +273,8 @@ void	*_dmalloc_heap_alloc(const unsigned int size)
     return HEAP_ALLOC_ERROR;
   }
   
-  dmalloc_message("WARNING: had to extend heap by %d more bytes to get page aligned %#lx",
-		  new_size, (unsigned long)heap_new);
+  dmalloc_message("WARNING: had to extend heap by %d more bytes to get page aligned %p",
+		  new_size, heap_new);
   
   diff_size = (long)heap_new % BLOCK_SIZE;
   if (diff_size == 0) {
